@@ -40,74 +40,70 @@ class UrbanoHandler:
         raise NotImplementedError(
             'get_shipping_label is not a method implemented for UrbanoHandler')
 
-    def get_default_payload(self, instance):
+    def get_default_payload(self, data):
         """
             This method generates by default all the necessary data with
             an appropriate structure for Urbano courier.
         """
 
-        try:
-            zone_code = instance.address.commune.zone_code
+        zone_code = data.address.commune.zone_code
 
-            if len(zone_code) == 4:
-                zone_code = '0' + zone_code
+        if len(zone_code) == 4:
+            zone_code = '0' + zone_code
 
-            payload = {
-                'anotacion': '',
-                'arco_hor': '',
-                'asegurado': '',
-                'cedibles': [],
-                'cod_barra': '',
-                'cod_cliente': instance.customer_rut,
-                'cod_rastreo': instance.vtex_reference,
-                'correo_elec': '',
-                'description': '',
-                'dir_entrega': instance.address.full_address,
-                'fech_emi_vent': instance.created_at.strftime('%d/%m/%Y'),
-                'fech_pro': instance.shipping_date.strftime('%d/%m/%Y'),
-                'fech_venc': (instance.shipping_date + timedelta(days=14)).strftime('%d/%m/%Y'),
-                'id_contrato': api_settings.URBANO['ID_CONTRATO'],
-                'id_direc': 0,
-                'importe': '',
-                'linea': '3', # TODO: ask about this.
-                'mecanizado': 'NO', # TODO: ask about this.
-                'med_pago': '',
-                'moneda': 'CLP',
-                'monto_asegurado': '',
-                'nom_autorizado': instance.customer_full_name,
-                'nom_autorizado_2': '',
-                'nom_cliente': instance.customer_full_name,
-                'nom_empresa': '',
-                'nom_urb': '',
-                'nro_doc_autorizado': instance.customer_rut,
-                'nro_doc_autorizado_2': '',
-                'nro_factura': '',
-                'nro_guia_trans': instance.wms_reference,
-                'nro_int': instance.address.unit,
-                'nro_o_compra': instance.nbr_reference,
-                'nro_telf': '',
-                'nro_telf_mobil': instance.customer_phone,
-                'nro_via': instance.address.number,
-                'peso_total': '',
-                'picking': 'NO', # TODO: ask about this.
-                'pieza_total': 1, # TODO: to define.
-                'productos': [],
-                'ref_direc': '',
-                'sell_codigo': '',
-                'sell_direcc': '',
-                'sell_nombre': '',
-                'sell_ubigeo': '',
-                'ubi_direc': zone_code,
-                'urgente': 'NO',
-                'venta_seller': 'NO',
-                'via_aereo': 'NO'
-            }
+        payload = {
+            'anotacion': '',
+            'arco_hor': '',
+            'asegurado': '',
+            'cedibles': [],
+            'cod_barra': '',
+            'cod_cliente': data.customer_rut,
+            'cod_rastreo': data.vtex_reference,
+            'correo_elec': '',
+            'description': '',
+            'dir_entrega': data.address.full_address,
+            'fech_emi_vent': data.created_at.strftime('%d/%m/%Y'),
+            'fech_pro': data.shipping_date.strftime('%d/%m/%Y'),
+            'fech_venc': (data.shipping_date + timedelta(days=14)).strftime('%d/%m/%Y'),
+            'id_contrato': api_settings.URBANO['ID_CONTRATO'],
+            'id_direc': 0,
+            'importe': '',
+            'linea': '3',  # TODO: ask about this.
+            'mecanizado': 'NO',  # TODO: ask about this.
+            'med_pago': '',
+            'moneda': 'CLP',
+            'monto_asegurado': '',
+            'nom_autorizado': data.customer_full_name,
+            'nom_autorizado_2': '',
+            'nom_cliente': data.customer_full_name,
+            'nom_empresa': '',
+            'nom_urb': '',
+            'nro_doc_autorizado': data.customer_rut,
+            'nro_doc_autorizado_2': '',
+            'nro_factura': '',
+            'nro_guia_trans': data.wms_reference,
+            'nro_int': data.address.unit,
+            'nro_o_compra': data.nbr_reference,
+            'nro_telf': '',
+            'nro_telf_mobil': data.customer_phone,
+            'nro_via': data.address.number,
+            'peso_total': '',
+            'picking': 'NO',  # TODO: ask about this.
+            'pieza_total': 1,  # TODO: to define.
+            'productos': [],
+            'ref_direc': '',
+            'sell_codigo': '',
+            'sell_direcc': '',
+            'sell_nombre': '',
+            'sell_ubigeo': '',
+            'ubi_direc': zone_code,
+            'urgente': 'NO',
+            'venta_seller': 'NO',
+            'via_aereo': 'NO'
+        }
 
-            logger.debug(payload)
-            return payload
-        except Exception as error:
-            logger.error(error)
-            raise Exception(error) from error
+        logger.debug(payload)
+        return payload
 
     def create_shipping(self, data):
         """
@@ -128,7 +124,8 @@ class UrbanoHandler:
                 response.update({'tracking_number': response['guia']})
                 return response
 
-            message_error = response.get('mensaje') or response.get('msg_error')
+            message_error = response.get(
+                'mensaje') or response.get('msg_error')
 
             raise ConnectorException(
                 message_error, 'Error requesting create shipping', 400
@@ -136,7 +133,8 @@ class UrbanoHandler:
 
         except ConnectorException as error:
             logger.error(error)
-            raise ConnectorException(error.message, error.description, error.code) from error
+            raise ConnectorException(
+                error.message, error.description, error.code) from error
 
     def get_tracking(self, identifier):
         """
@@ -162,7 +160,8 @@ class UrbanoHandler:
 
         except ConnectorException as error:
             logger.error(error)
-            raise ConnectorException(error.message, error.description, error.code) from error
+            raise ConnectorException(
+                error.message, error.description, error.code) from error
 
     def get_events(self, raw_data):
         """
